<?php
/**
 * Aberdeen functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Aberdeen
 */
 
if ( ! function_exists( 'aberdeen_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function aberdeen_setup() {

	/*
	 * Add Redux Framework
	 */
	require get_template_directory() . '/admin/admin-init.php';

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Aberdeen, use a find and replace
	 * to change 'aberdeen' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'aberdeen', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'aberdeen' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'aberdeen_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	
	// Declares custom header support
	add_theme_support( 'custom-header' );
	
	// Declares WooCommerce support
	add_theme_support( 'woocommerce' );
	
	// Declares Sensei support
	add_theme_support( 'sensei' );
	
	// Declares JetPack Infinite Scroll support
	add_theme_support( 'infinite-scroll', array(
    'container' => 'content-area',
    'footer' => 'page',
	) );
	
}
endif; // aberdeen_setup
add_action( 'after_setup_theme', 'aberdeen_setup' );

// Initialize the update checker.
require 'inc/update.php';
$example_update_checker = new ThemeUpdateChecker(
    'aberdeen-plus',
    'http://www.stevenkellow.com/aberdeen/aberdeen-plus.json'
);

// Set notice to install Redux Framework plugin if haven't already
add_action('admin_notices', 'redux_notification');

function redux_notification() {
	global $current_user ;
        $user_id = $current_user->ID;
        /* Check that the user hasn't already clicked to ignore the message */
	if ( (! class_exists( 'ReduxFrameworkInstances')) && (! get_user_meta($user_id, 'redux_ignore_notice')) ) {
        echo '<div class="updated"><p>'; 
        printf(__('Make sure to install Redux Framework from the Plugins > Install Plugins menu to get your theme options! | <a href="%1$s">Hide Notice</a>', 'aberdeen'), '?redux_ignore=0', 'aberdeen');
        echo "</p></div>";
	}
}

add_action('admin_init', 'redux_notification_check');

function redux_notification_check() {
	global $current_user;
        $user_id = $current_user->ID;
        /* If user clicks to ignore the notice, add that to their user meta */
        if ( isset($_GET['redux_ignore']) && '0' == $_GET['redux_ignore'] ) {
             add_user_meta($user_id, 'redux_ignore_notice', 'true', true);
	}
}

// Makes sure Redux dev mode is off
if ( ! function_exists( 'redux_disable_dev_mode_plugin' ) ) {
        function redux_disable_dev_mode_plugin( $redux ) {
            if ( $redux->args['opt_name'] != 'redux_demo' ) {
                $redux->args['dev_mode'] = false;
                $redux->args['forced_dev_mode_off'] = false;
            }
        }
        add_action( 'redux/construct', 'redux_disable_dev_mode_plugin' );
    }
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function aberdeen_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'aberdeen_content_width', 640 );
}
add_action( 'after_setup_theme', 'aberdeen_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aberdeen_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'aberdeen' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'aberdeen_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function aberdeen_scripts( $theme_options ) {
	global $theme_options;
	wp_enqueue_style( 'aberdeen-style', get_stylesheet_uri() );
	wp_enqueue_script( 'aberdeen-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'aberdeen-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	if ( $theme_options['show-sticky-nav-bar'] == true ){
		wp_enqueue_script( 'aberdeen-sticky-nav', get_template_directory_uri() . '/js/sticky-nav.js', array(), '20151105', true );
	}
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	// Enqueues font awesome stylesheet
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css'); 
}
add_action( 'wp_enqueue_scripts', 'aberdeen_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

// Initialises Redux Framework for theme options
require_once ( 'inc/theme-options-config.php');
function removeDemoModeLink() {
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}
add_action('init', 'removeDemoModeLink');

// Ensure cart contents update when products are added to the cart via AJAX
add_filter( 'woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment' );

function woocommerce_header_add_to_cart_fragment( $fragments ) {
	ob_start();
	?>
	<a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e( 'View your shopping cart', 'aberdeen' ); ?>"><?php echo '<i class="fa fa-shopping-cart"></i>&nbsp;' . WC()->cart->cart_contents_count; ?> - <?php echo WC()->cart->get_cart_total(); ?></a>
	<?php
	
	$fragments['a.cart-contents'] = ob_get_clean();
	
	return $fragments;
}

// Adds social sharing options to WooCommerce products
function woocommerce_share(){
	include get_template_directory() .'/template-parts/social-media-sharing.php';
}

add_action( 'woocommerce_single_product_summary', 'woocommerce_share', 50 );

// Limits homepage archive widget to last six months
function my_limit_archives( $args ) {
	global $theme_options;
	if ( $theme_options['archive-months'] == '8' ){
		$limit = 10000;
	} else {
		$limit = intval( $theme_options['archive-months'] ) - 1;
	}
    $args['limit'] = $limit;
    return $args;
}
add_filter( 'widget_archives_args', 'my_limit_archives' );

// Sets a higher excerpt length
function custom_excerpt_length( $length ) {
	return 85;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

// Replaces the excerpt "more" text by a link
function excerpt_more($more) {
	return '&nbsp;&mdash;<a href="'. get_permalink() . '"> Read more &rarr;</a>';
}
add_filter('excerpt_more', 'excerpt_more');

// Replaces the content "more" text link
function content_more() {
	return '<a href="' . get_permalink() . '"> Read more &rarr;</a>';
}
add_filter( 'the_content_more_link', 'content_more' );

// Includes social media links for users' author-box
require get_template_directory() . '/inc/user-social-links.php';

// Choose sidebar alignment
function sidebar_align( $theme_options ){
	global $theme_options;
	if ( $theme_options['sidebar-align'] == '1' ) {
		wp_enqueue_style( 'sidebar-left', get_template_directory_uri() . '/css/layouts/sidebar-left.css' );
	} else {
		wp_enqueue_style( 'sidebar-right', get_template_directory_uri() . '/css/layouts/sidebar-right.css' );
	}
}
add_action( 'wp_enqueue_scripts', 'sidebar_align' );

// Choose logo alignment
function logo_align( $theme_options ){
	global $theme_options;
	if ( $theme_options['show-header-logo'] == true ){
		switch ( $theme_options['logo-align'] ){
			case '1':
				wp_enqueue_style( 'logo-top', get_template_directory_uri() . '/css/layouts/logo-top.css' );
				break;
			case '2':
				wp_enqueue_style( 'logo-left', get_template_directory_uri() . '/css/layouts/logo-left.css' );
				break;
			case '3':
				wp_enqueue_style( 'logo-right', get_template_directory_uri() . '/css/layouts/logo-right.css' );
				break;
		}
	}
}
add_action( 'wp_enqueue_scripts', 'logo_align' );

// Adds custom styling to WordPress editor to match default theme body
function add_editor_styles() {
    add_editor_style( '/css/editor-style.css' );
}
add_action( 'admin_init', 'add_editor_styles' );

// Enqueues the main CSS styles for the theme based on choice in theme options panel
function main_color_scheme_set( $theme_options ) {
global $theme_options;
if( isset( $theme_options['color-scheme'] ) ) {
		switch ( $theme_options['color-scheme'] ) {
			case '2':
				wp_enqueue_style( 'aberdeen-blue', get_template_directory_uri() . '/css/blue.css' );
				break;
			case '3':
				wp_enqueue_style( 'aberdeen-green', get_template_directory_uri() . '/css/green.css');
				break;
			case '4':
				wp_enqueue_style( 'aberdeen-orange', get_template_directory_uri() . '/css/orange.css' );
				break;
			case '5':
				wp_enqueue_style( 'aberdeen-purple', get_template_directory_uri() . '/css/purple.css' );
				break;
			case '6':
				wp_enqueue_style( 'aberdeen-red', get_template_directory_uri() . '/css/red.css' );
				break;			
			case '7':
				wp_enqueue_style( 'aberdeen-pink', get_template_directory_uri() . '/css/pink.css' );
				break;
			case '8':
				wp_enqueue_style( 'aberdeen-black', get_template_directory_uri() . '/css/black.css' );
				break;
			case '9':
				wp_enqueue_style( 'aberdeen-grey', get_template_directory_uri() . '/css/grey.css' );
				break;
			case '10':
				wp_enqueue_style( 'aberdeen-light-blue', get_template_directory_uri() . '/css/light-blue.css' );
				break;
			case '11':
				wp_enqueue_style( 'aberdeen-light-green', get_template_directory_uri() . '/css/light-green.css' );
				break;
			default:
				wp_enqueue_style( 'aberdeen-custom', get_template_directory_uri() . '/css/blue.css' );
				break;
		}
	} else {
		wp_enqueue_style( 'aberdeen-custom', get_template_directory_uri() . '/css/blue.css' );
	}
}
add_action( 'wp_enqueue_scripts', 'main_color_scheme_set' );

// Sets homepage template depending on whether we want to display latest posts or a static page
$template = '/template-parts/content-home';

function aberdeen_filter_front_page_template( $template ) {
    return is_home() ? '' : $template;
}
add_filter( 'frontpage_template', 'aberdeen_filter_front_page_template' );

// Support for WooThemes Sensei plugin
if (in_array( 'sensei-master/woothemes-sensei.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ){
global $woothemes_sensei;
remove_action( 'sensei_before_main_content', array( $woothemes_sensei->frontend, 'sensei_output_content_wrapper' ), 10 );
remove_action( 'sensei_after_main_content', array( $woothemes_sensei->frontend, 'sensei_output_content_wrapper_end' ), 10 );

add_action('sensei_before_main_content', 'theme_wrapper_start', 10);
add_action('sensei_after_main_content', 'theme_wrapper_end', 10);

function theme_wrapper_start() {
  echo '<div id="primary" class="content-area"><main id="main" class="site-main" role="main">';
}

function theme_wrapper_end() {
  echo '</main><!-- #main -->
	</div><!-- #primary -->';
	get_sidebar();
}
}

// Adds site breadcrumb functionality
require get_template_directory() . '/inc/breadcrumbs.php';

// Adds a subtitle box to the main column on the Post edit screens.
require get_template_directory() . '/inc/subtitle.php';

// Adds a post width box to the main column on the Post edit screens.
require get_template_directory() . '/inc/full-width.php';

// Adds support for page social share counts
require get_template_directory() . '/inc/share-counts.php';