<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Aberdeen
 */

global $theme_options;

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<div id="page" class="hfeed site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'aberdeen' ); ?></a>
	<header id="masthead" class="site-header" role="banner">
	<?php if (get_header_image() != '') {?>
		<!-- Custom header support -->
		<style>.site-header {background-image: url("<?php header_image(); ?>"); background-size: cover; background-position: center top;}</style>
		<?php } ?>
		<!-- Header search form -->
		<div class="site-search">
		<form class="header-search" method="get" id="searchform" action="<?php echo esc_url( home_url() ); ?>/">
		<input type="text" size="18" value="<?php echo esc_html( $s ); ?>" name="s" id="header-search" />
		<input type="submit" id="header-search" value="Search" class="submit" />
		</form>
		</div>
		
		<div class="site-branding">
		<?php if ( $theme_options['show-header-logo'] == true ){
			// Create div for site logo for proper positioning ?>
			<div class="site-header-logo">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><img class="site-logo" src="<?php echo $theme_options['header-logo-image']['url']; ?>"></a>
			</div>
			<div class="site-header-content">
			<?php }
			if ( is_front_page() && is_home() ){?>
			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
			<?php } else { ?>
			<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			<?php }
			get_template_part( 'template-parts/social-media', 'header' ); ?>
			<p class="site-description"><?php bloginfo( 'description' ); ?></p>
		<?php if ( $theme_options['show-header-logo'] == true ){ ?>
		</div>
		<?php } ?>
		</div><!-- .site-branding -->
		<nav id="site-navigation" class="main-navigation" role="navigation">
		<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="fa fa-bars fa-2x"></i></button>
		<?php 
		// Applies different class to main menu if logged in so sticky nav bar displays correctly
		if ( is_admin_bar_showing() ) {
				$menu_class = 'menu admin-bar';
		} else {
				$menu_class = 'menu';
		}
		wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu', 'menu_class' => $menu_class) );
		
		// WooCommerce nav bar options
		if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		if ( $theme_options['wc-cart-nav-bar'] !== '1' ) {
		if ( ( ( $theme_options['wc-cart-nav-bar'] == '2' ) && ( WC()->cart->cart_contents_count > 0 ) ) || $theme_options['wc-cart-nav-bar'] == '3' ){?>
		<a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e( 'View your shopping cart', 'aberdeen' ); ?>"><?php echo '<i class="fa fa-shopping-cart"></i>&nbsp;' . WC()->cart->cart_contents_count; ?> - <?php echo WC()->cart->get_cart_total(); ?></a>
		<?php } } }?>
		</nav><!-- #site-navigation -->
	</header><!-- #masthead -->
	<div id="content" class="site-content">