<?php
/**
*
* Adds width meta box to posts
*
* @package Aberdeen
*
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
function aberdeen_add_width_box() {

		add_meta_box(
			'aberdeen_width_id',
			__( 'Post width', 'aberdeen' ),
			'aberdeen_width_box_callback',
			array( 'post', 'page'),
			'side',
			'core'
		);
}
add_action( 'add_meta_boxes', 'aberdeen_add_width_box' );

/**
 * Prints the box content.
 * 
 * @param WP_Post $post The object for the current post/page.
 */
function aberdeen_width_box_callback( $post ) {

	// Add a nonce field so we can check for it later.
	wp_nonce_field( 'aberdeen_width_box_data', 'aberdeen_width_box_nonce' );

	?>

	 <div>
            <select name="aberdeen_width">
                <?php 
                    $option_values = array('Normal', 'Full width');

                    foreach($option_values as $key => $value) 
                    {
                        if($value == get_post_meta($post->ID, 'width', true))
                        {
                            ?>
                                <option selected><?php echo $value; ?></option>
                            <?php    
                        }
                        else
                        {
                            ?>
                                <option><?php echo $value; ?></option>
                            <?php
                        }
                    }
                ?>
            </select>
        </div>
<?php
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function aberdeen_width_box_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['aberdeen_width_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['aberdeen_width_box_nonce'], 'aberdeen_width_box_data' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */
	
	// Make sure that it is set.
	if ( isset( $_POST['aberdeen_width'] ) ) {
		$aberdeen_width_value = $_POST['aberdeen_width'];
	}

	// Update the meta field in the database.
	update_post_meta( $post_id, 'width', $aberdeen_width_value );
}
add_action( 'save_post', 'aberdeen_width_box_data' );