<?php
/**
*
* Adds subtitle meta box to posts
*
* @package Aberdeen
*
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
function aberdeen_add_meta_box() {

		add_meta_box(
			'aberdeen_sectionid',
			__( 'Subtitle', 'aberdeen' ),
			'aberdeen_meta_box_callback',
			'post',
			'advanced',
			'high'
		);
}
add_action( 'add_meta_boxes', 'aberdeen_add_meta_box' );

/**
 * Prints the box content.
 * 
 * @param WP_Post $post The object for the current post/page.
 */
function aberdeen_meta_box_callback( $post ) {

	// Add a nonce field so we can check for it later.
	wp_nonce_field( 'aberdeen_save_meta_box_data', 'aberdeen_meta_box_nonce' );

	/*
	 * Use get_post_meta() to retrieve an existing value
	 * from the database and use the value for the form.
	 */
	$subtitle = get_post_meta( $post->ID, 'subtitle', true );

	echo '<input type="text" id="aberdeen_subtitle" name="aberdeen_subtitle" value="' . esc_attr( $subtitle ) . '" size="80" />';
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function aberdeen_save_meta_box_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['aberdeen_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['aberdeen_meta_box_nonce'], 'aberdeen_save_meta_box_data' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */
	
	// Make sure that it is set.
	if ( ! isset( $_POST['aberdeen_subtitle'] ) ) {
		return;
	}

	// Sanitize user input.
	$my_data = sanitize_text_field( $_POST['aberdeen_subtitle'] );

	// Update the meta field in the database.
	update_post_meta( $post_id, 'subtitle', $my_data );
}
add_action( 'save_post', 'aberdeen_save_meta_box_data' );