<?php
    /**
     * ReduxFramework Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */
    if ( ! class_exists( 'Redux' ) ) {
        return;
    }
    // This is your option name where all the Redux data is stored.
    $opt_name = "theme_options";
    // This line is only for altering the demo. Can be easily removed.
    // $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field example.
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();

    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Theme Options', 'aberdeen' ),
        'page_title'           => __( 'Theme Options', 'aberdeen' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', 'aberdeen' ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', 'aberdeen' ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', 'aberdeen' ),
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/reduxframework',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://www.linkedin.com/company/redux-framework',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'aberdeen' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'aberdeen' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'aberdeen' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'aberdeen' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'aberdeen' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Social Media', 'aberdeen' ),
        'id'               => 'social-media-options',
        'desc'             => __( 'These are really basic fields!', 'aberdeen' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-share'
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'            => __( 'Header Links', 'aberdeen' ),
        'desc'             => __( 'Enter your links to social media profiles & products here', 'aberdeen' ),
        'id'               => 'social-media-links',
        'subsection'       => true,
        'customizer_width' => '700px',
        'fields'           => array(
			array(
				'id'       => 'sml-amazon',
                'type'     => 'text',
                'title'    => __( 'Amazon', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your Amazon page/product', 'aberdeen' ),
				'validate' => 'url'
			),
			array(
				'id'       => 'sml-apple-store',
                'type'     => 'text',
                'title'    => __( 'Apple App Store', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your App Store product', 'aberdeen' ),
				'validate' => 'url'
			),
            array(
                'id'       => 'sml-facebook',
                'type'     => 'text',
                'title'    => __( 'Facebook', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your Facebook profile', 'aberdeen' ),
				'placeholder' => 'https://www.facebook.com/YOU',
				'validate' => 'url'
            ),
			array(
                'id'       => 'sml-flickr',
                'type'     => 'text',
                'title'    => __( 'Flickr', 'aberdeen' ),
                'desc'     => __( 'Enter your Flickr username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-github',
                'type'     => 'text',
                'title'    => __( 'Github', 'aberdeen' ),
                'desc'     => __( 'Enter your GitHub username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
				'id'       => 'sml-google-play',
                'type'     => 'text',
                'title'    => __( 'Google Play', 'aberdeen' ),
				'subtitle' => __( 'Android App Store', 'aberdeen'),
                'desc'     => __( 'Enter the full link to your Google Play product', 'aberdeen' ),
				'validate' => 'url'
			),
			array(
                'id'       => 'sml-google-plus',
                'type'     => 'text',
                'title'    => __( 'Google+', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your Google+ profile', 'aberdeen' ),
				'validate' => 'url'
            ),
			array(
                'id'       => 'sml-instagram',
                'type'     => 'text',
                'title'    => __( 'Instagram', 'aberdeen' ),
                'desc'     => __( 'Enter your Instragram username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-lastfm',
                'type'     => 'text',
                'title'    => __( 'Last.fm', 'aberdeen' ),
                'desc'     => __( 'Enter your Last.fm username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-linkedin',
                'type'     => 'text',
                'title'    => __( 'LinkedIn', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your LinkedIn profile', 'aberdeen' ),
				'validate' => 'url'
            ),
			array(
                'id'       => 'sml-paypal',
                'type'     => 'text',
                'title'    => __( 'PayPal', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your PayPal profile', 'aberdeen' ),
				'validate' => 'url'
            ),
			array(
                'id'       => 'sml-pinterest',
                'type'     => 'text',
                'title'    => __( 'Pinterest', 'aberdeen' ),
                'desc'     => __( 'Enter your Pinterest username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
				'id'	=>	'sml-reddit',
				'type'	=>	'text',
				'title'	=>	__( 'reddit', 'aberdeen' ),
				'desc'	=>	__( 'Enter the full link to your reddit subreddit or user profile', 'aberdeen' ),
				'validate' =>	'url'
			),
			array(
				'id'       => 'sml-rss',
                'type'     => 'text',
                'title'    => __( 'RSS Feed', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your RSS feed', 'aberdeen' ),
				'placeholder' => site_url( '/feed/' ),
				'validate' => 'url'
			),
			array(
                'id'       => 'sml-tumblr',
                'type'     => 'text',
                'title'    => __( 'Tumblr', 'aberdeen' ),
                'desc'     => __( 'Enter your Tumblr username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-twitter',
                'type'     => 'text',
                'title'    => __( 'Twitter', 'aberdeen' ),
                'desc'     => __( 'Enter your Twitter username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-vimeo',
                'type'     => 'text',
                'title'    => __( 'Vimeo', 'aberdeen' ),
                'desc'     => __( 'Enter the full link to your Vimeo profile', 'aberdeen' ),
				'validate' => 'url'
            ),
			array(
                'id'       => 'sml-vine',
                'type'     => 'text',
                'title'    => __( 'Vine', 'aberdeen' ),
                'desc'     => __( 'Enter your Vine username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),
			array(
                'id'       => 'sml-youtube',
                'type'     => 'text',
                'title'    => __( 'YouTube', 'aberdeen' ),
                'desc'     => __( 'Enter your YouTube username', 'aberdeen' ),
				'validate' => 'no_special_chars'
            ),

        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Sharing', 'aberdeen' ),
        'id'         => 'social-media-sharing',
        'desc'       => __( 'Options for social sharing icons on posts and pages', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'share-posts',
                'type'     => 'switch',
                'title'    => __( 'Show sharing bar on posts?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'share-pages',
                'type'     => 'switch',
                'title'    => __( 'Show sharing bar on pages?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
			   'id' => 'section-start',
			   'type' => 'section',
			   'title' => __('Networks', 'aberdeen'),
			   'subtitle' => __('Choose the networks you would like to users to share posts with', 'aberdeen'),
			   'indent' => true 
			),
            array(
                'id'       => 'facebook-sharing',
                'type'     => 'switch',
                'title'    => __( 'Facebook', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'google-plus-sharing',
                'type'     => 'switch',
                'title'    => __( 'Google+', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'linkedin-sharing',
                'type'     => 'switch',
                'title'    => __( 'LinkedIn', 'aberdeen' ),
                'default'  => true,
            ),
			array(
				'id'	=>	'pocket-sharing',
				'type'	=>	'switch',
				'title'	=>	__( 'Pocket', 'aberdeen' ),
				'default' => false,
			),
			array(
				'id'	=>	'reddit-sharing',
				'type'	=>	'switch',
				'title'	=>	__( 'reddit', 'aberdeen' ),
				'default' => false,
			),
			array(
				'id'       => 'tumblr-sharing',
				'type'     => 'switch',
				'title'    => __( 'Tumblr', 'aberdeen' ),
				'default'  => false,
				),			
			array(
                'id'       => 'twitter-sharing',
                'type'     => 'switch',
                'title'    => __( 'Twitter', 'aberdeen' ),
                'default'  => true,
            ),
			array(
				'id'       => 'email-sharing',
				'type'     => 'switch',
				'title'    => __( 'E-mail', 'aberdeen' ),
				'default'  => true,            
			),
			array(
				'id'       => 'print-sharing',
				'type'     => 'switch',
				'title'    => __( 'Print', 'aberdeen' ),
				'default'  => true,            
			),				
			),
        )
    ) ;

    Redux::setSection( $opt_name, array(
        'title' => __( 'Color Selection', 'aberdeen' ),
        'id'    => 'color',
        'desc'  => __( '', 'aberdeen' ),
        'icon'  => 'el el-brush'
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Color Schemes', 'aberdeen' ),
        'id'         => 'color-settings',
        'desc'       => __( 'Choose how colors are displayed on your site ', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
				'id'		=> 'color-scheme',
				'type'		=> 'select',
				'title' 	=> __('Color Scheme', 'aberdeen'),
				'subtitle'	=> __('Select a color scheme or choose to make your own', 'aberdeen'),
				'options' 	=> array( '1' => 'custom', '2' => 'blue', '3' => 'green', '4' => 'orange', '5' => 'purple', '6' => 'red', '7' => 'pink', '8' => 'black', '9' => 'grey', '10' => 'light blue', '11' => 'light green' ),
				'default' => '2',
			),
            array(
                'id'       => 'main-color',
                'type'     => 'color',
                'output'   =>	array(
					'background-color'	=>	'hr, .site-header, .site-footer, button, .button, input[type="submit"], .submit:hover, .woocommerce #respond, input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce .woocommerce-message .button, .woocommerce input.button, .woocommerce-page #content input.button, .woocommerce-page input.button, .woocommerce a.button, .bypostauthor > .comment-body > .comment-meta > .comment-author.vcard',
					'border-color'		=>	'input[type="text"], input[type="email"], input[type="url"], input[type="password"], input[type="search"], textarea, button:hover, .button:hover, input[type="submit"]:hover, .submit, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, table td, table th, .main-navigation ul ul, .author-box, #bbp_topic_submit, #bbp_reply_submit .subscription-toggle',
					'border-bottom-color'	=>	'article, .fixed, .widget-title',
					'border-top-color'	=>	'.fixed, .widget-title',
					'color'	=>	'blockquote:before, q:before, button:hover, .button:hover, input[type="submit"]:hover, .submit, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, a, .sharing-si > span, .woocommerce-message, #bbp_topic_submit:hover, #bbp_reply_submit:hover, .subscription-toggle:hover'
					),
                'title'    => __( 'Main site color', 'aberdeen' ),
                'subtitle' => __( 'Pick a main color to use in your custom color theme (default: #181754).', 'aberdeen' ),
                'default'  => '#181754',
				'required' => array( 'color-scheme', '=', '1' )
            ),
			array(
                'id'       => 'secondary-color',
                'type'     => 'color',
                'output'		=>	array(
					'border-bottom-color' => '.site-info > p > a:hover',
					'color'	=>	'a:hover, a:focus, a:active'
					),
                'title'    => __( 'Secondary site color', 'aberdeen' ),
                'subtitle' => __( 'Pick a secondary color to use in your custom color theme (default: #181754).', 'aberdeen' ),
                'default'  => '#181754',
				'required' => array( 'color-scheme', '=', '1' )
            ),
			array(
                'id'       => 'visited-link-color',
                'type'     => 'color',
                'output'		=>	array(
					'color'	=>	'a:visited'
					),
                'title'    => __( 'Visited link color', 'aberdeen' ),
                'subtitle' => __( 'Pick a color for already-visited links in your custom color theme (default: #800080).', 'aberdeen' ),
                'default'  => '#800080',
				'required' => array( 'color-scheme', '=', '1' )
            ),
			array(
                'id'       => 'background-color-choice',
                'type'     => 'button_set',
                'title'    => __( 'Background options', 'aberdeen' ),
                'desc'     => __( 'Choose how to color the background', 'aberdeen' ),
                'options'  => array(
                    '1' => 'White',
                    '2' => 'Color',
					'3' => 'Image',
                ),
                'default'  => '1',
				'required' => array( 'color-scheme', '=', '1' ),
            ),
			array(
                'id'       => 'header-color',
                'type'     => 'color',
                'output'		=>	array(
					'color'	=>	'.site-title > a, .site-title > a:visited, .site-description, .header-si > span, .site-footer, .site-info > p > a',
					'border-bottom-color' => '.site-info > p > a'
					),
                'title'    => __( 'Header and footer text color', 'aberdeen' ),
                'subtitle' => __( 'Pick the text color for the header and footer (default: #ffffff).', 'aberdeen' ),
                'default'  => '#ffffff',
            ),
			array(
                'id'       => 'background-color',
                'type'     => 'color',
                'output'		=>	array(
					'background-color'	=>	'body'
					),
                'title'    => __( 'Background color', 'aberdeen' ),
                'subtitle' => __( 'Pick a color for the site background (default: #ffffff).', 'aberdeen' ),
				'desc'     => __( 'We recommend using the same color as your site&#39;s main color', 'aberdeen' ),
                'default'  => '#ffffff',
				'required' => array( 'background-color-choice', '=', '2' ),
            ),
			array(         
				'id'       => 'background-image',
				'type'     => 'background',
				'title'    => __('Background image', 'aberdeen'),
				'subtitle' => __('Choose the background image', 'aberdeen'),
				'default'  => array(
					'background-color' => '#ffffff',
				),
				'required' => array( 'background-color-choice', '=', '3' ),
			),
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'  => __( 'Typography', 'aberdeen' ),
        'id'     => 'typography',
        'desc'   => __( 'Choose how you would like your site text to look', 'aberdeen' ),
        'icon'   => 'el el-font',
        'fields' => array(
            array(
                'id'       => 'opt-typography-body',
                'type'     => 'typography',
                'title'    => __( 'Body Font', 'aberdeen' ),
                'subtitle' => __( 'Specify the body font properties.', 'aberdeen' ),
				'font-style' => 'false',
				'units'    => 'false',
				'output'   => array( '.entry-conent' ),
                'google'   => true,
                'default'  => array(
                    'color'       => '#000000',
                    'font-size'   => '16px',
                    'font-family' => 'Roboto',
                    'font-style'  => '300',
					'line-height' => '24px',
					'text-align'  => 'left',
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Header and Layout', 'aberdeen' ),
        'id'    => 'header-layout',
        'desc'  => __( '', 'aberdeen' ),
        'icon'  => 'el el-picture'
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Header', 'aberdeen' ),
        'id'         => 'header-options',
        'desc'       => __( 'Choose options for the header', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-header-logo',
                'type'     => 'switch',
                'title'    => __( 'Show header logo?', 'aberdeen' ),
                'subtitle' => __( 'Choose whether to show a logo in the site header', 'aberdeen' ),
                'default'  => false,
            ),
			array(
                'id'       => 'logo-align',
                'type'     => 'button_set',
                'title'    => __( 'Logo position', 'aberdeen' ),
                'desc'     => __( 'Choose the position where you want to display the logo', 'aberdeen' ),
                'options'  => array(
                    '1' => 'Top',
                    '2' => 'Left',
					'3' => 'Right',
                ),
                'default'  => '2',
				'required' => array( 'show-header-logo', '=', true ),
            ),
			array(
                'id'       => 'header-logo-image',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Header logo', 'aberdeen' ),
                'compiler' => 'true',
                'desc'     => __( 'Recommended size: 400px x 150px', 'aberdeen' ),
                'subtitle' => __( 'Choose a logo to be used in the site&#39;s header', 'aberdeen' ),
				'required' => array( 'show-header-logo', '=', true ),
			),
			array(
				'id'       => 'show-sticky-nav-bar',
				'type'     => 'switch',
				'title'    => __( 'Sticky nav bar to top when scrolling?', 'aberdeen' ),
				'default'  => false,
			),
			array(
				'id'	   => 'wc-cart-nav-bar',
				'type'	   => 'button_set',
				'title'    => __( 'WooCommerce cart navigation options', 'aberdeen' ),
				'desc'     => __( 'Choose how the WooCommerce cart is displayed in the nav bar', 'aberdeen' ),
				'options'  => array(
					'1'    => 'Hidden',
					'2'    => 'If not empty',
					'3'    => 'Always'
				),
				'default'  => '2'
			),
        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Footer', 'aberdeen' ),
        'id'         => 'footer-options',
        'desc'       => __( 'Choose options for the footer', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
				array(
					'id'       => 'show-footer-wordpress',
					'type'     => 'switch',
					'title'    => __( 'Show WordPress link in footer?', 'aberdeen' ),
					'desc' => __( 'Choose whether to show "Proudly powered by WordPress" in the footer', 'aberdeen' ),
					'default'  => true,
				),
				array(
					'id'       => 'show-footer-sitename',
					'type'     => 'button_set',
					'title'    => __( 'Site copyright', 'aberdeen' ),
					'desc'	   => __( 'Choose what to show along with the site copyright', 'aberdeen' ),
					'options'  => array(
						'1'	=> 'Nothing',
						'2' => 'Site name',
						'3' => 'Custom text',
					),
					'default'  => '1'
				),
				array(
					'id'       => 'footer-custom-text',
					'type'     => 'text',
					'title'    => __( 'Custom footer text', 'aberdeen' ),
					'desc'	   => __( 'Defaults to blog title', 'aberdeen' ),
					'subtitle' => __( 'Displays next to copyright', 'aberdeen' ),
					'validate' => 'no_special_chars',
					'required' => array( 'show-footer-sitename', '=', '3' )
				),
			)
		)
	);

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Sidebar', 'aberdeen' ),
        'id'         => 'sidebar-options',
        'desc'       => __( 'Choose options for the sidebar', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-homepage-sidebar',
                'type'     => 'switch',
                'title'    => __( 'Show sidebar on homepage?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'sidebar-align',
                'type'     => 'button_set',
                'title'    => __( 'Sidebar side', 'aberdeen' ),
                'desc'     => __( 'Choose the side you want the sidebar on.', 'aberdeen' ),
                'options'  => array(
                    '1' => 'Left',
                    '2' => 'Right',
                ),
                'default'  => '2'
            ),
			array(
				'id'		=> 'sidebar-months',
				'type'		=> 'select',
				'title' 	=> __('Archive limit', 'aberdeen'),
				'subtitle'	=> __('Choose how many months to display in the sidebar archive', 'aberdeen'),
				'options' 	=> array( '1' => '0', '2' => '1', '3' => '2', '4' => '3', '5' => '4', '6' => '5', '7' => '6', '8' => 'No limit'),
				'default' => '6',
			),
        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Breadcrumbs', 'aberdeen' ),
        'id'         => 'breadcrumbs-options',
        'desc'       => __( 'Choose options for the site&#39;s breadcrumbs', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
				'id'       => 'show-breadcrumbs-single',
				'type'     => 'switch',
				'title'    => __( 'Display breadcrumbs on posts?', 'aberdeen' ),
				'default'  => true,
			),
			array(
				'id'       => 'show-breadcrumbs-page',
				'type'     => 'switch',
				'title'    => __( 'Display breadcrumbs on pages?', 'aberdeen' ),
				'default'  => false,
			),
			array(
				'id'		=> 'breadcrumb-sep',
				'type'		=> 'select',
				'title' 	=> __('Breadcrumb separator', 'aberdeen'),
				'subtitle'	=> __('Choose a character as your breadcrumb seperator', 'aberdeen'),
				'options' 	=> array( '1' => '&gt;', '2' => '&raquo;', '3' => '&#47;', '4' => '&rarr;', '5' => '&#124;'),
				'default' => '1',
			),
        )
    ) );
	
	
	Redux::setSection( $opt_name, array(
        'title'            => __( 'Posts and Pages', 'aberdeen' ),
        'id'               => 'post-page-options',
        'desc'             => __( 'Options for posts and pages', 'aberdeen' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-pencil'
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Homepage', 'aberdeen' ),
        'id'         => 'homepage-options',
        'desc'       => __( 'Choose what&#39;s shown on the homepage', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-homepage-title',
                'type'     => 'switch',
                'title'    => __( 'Show the page title on the homepage?', 'aberdeen' ),
                'default'  => false,
            ),
			array(
                'id'       => 'show-homepage-rp',
                'type'     => 'switch',
                'title'    => __( 'Show recent posts on homepage?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-homepage-cat',
                'type'     => 'switch',
                'title'    => __( 'Show category listings on homepage?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-excerpt',
                'type'     => 'switch',
                'title'    => __( 'Show excerpts of posts on homepage?', 'aberdeen' ),
				'desc'	   => __( 'Use excerpts if no read more tag is available', 'aberdeen' ),
                'default'  => true,
            ),
        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Post header', 'aberdeen' ),
        'id'         => 'post-header',
        'desc'       => __( 'Choose what&#39;s shown in a post&#39;s header', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-author',
                'type'     => 'switch',
                'title'    => __( 'Show author?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-post-date',
                'type'     => 'switch',
                'title'    => __( 'Show post date?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-categories',
                'type'     => 'switch',
                'title'    => __( 'Show categories?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-tags',
                'type'     => 'switch',
                'title'    => __( 'Show tags?', 'aberdeen' ),
                'default'  => false,
            ),
			array(
                'id'       => 'show-comment-count',
                'type'     => 'switch',
                'title'    => __( 'Show comment count?', 'aberdeen' ),
                'default'  => false,
            ),
        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Post footer', 'aberdeen' ),
        'id'         => 'post-footer',
        'desc'       => __( 'Choose what&#39;s shown in a post&#39;s footer', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-footer-categories',
                'type'     => 'switch',
                'title'    => __( 'Show categories in footer?', 'aberdeen' ),
                'default'  => false,
            ),
			array(
                'id'       => 'show-footer-tags',
                'type'     => 'switch',
                'title'    => __( 'Show tags in footer?', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-author-box',
                'type'     => 'switch',
                'title'    => __( 'Show author information box?', 'aberdeen' ),
                'default'  => false,
            ),
			array(
                'id'       => 'show-post-nav',
                'type'     => 'switch',
                'title'    => __( 'Show navigation links?', 'aberdeen' ),
				'desc'     => __( 'Shows links to previous and next posts', 'aberdeen' ),
                'default'  => true,
            ),
			array(
                'id'       => 'show-post-trackbacks',
                'type'     => 'switch',
                'title'    => __( 'Show trackback/pingbacks on posts?', 'aberdeen' ),
                'default'  => false,
            ),
        )
    ) );
	
	Redux::setSection( $opt_name, array(
        'title'      => __( 'Page footer', 'aberdeen' ),
        'id'         => 'page-footer',
        'desc'       => __( 'Choose what&#39;s shown in a page&#39;s footer', 'aberdeen' ),
        'subsection' => true,
        'fields'     => array(
			array(
                'id'       => 'show-page-trackbacks',
                'type'     => 'switch',
                'title'    => __( 'Show trackback/pingbacks on pages?', 'aberdeen' ),
                'default'  => false,
            ),
		)
    ) );
	
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'aberdeen' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'aberdeen' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }