<?php
/**
 * Template part for displaying most recent posts on front page.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Aberdeen
 */

global $theme_options;

// Sets up a paginated query to get most recent posts
$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
$post_query = new WP_Query( array( 'post_type' => 'post', 'paged' => $paged ) );

// The Loop
if ( $post_query->have_posts() ) {
	while ( $post_query->have_posts() ) : $post_query->the_post(); ?>
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<header class="entry-header">
		<?php if ( $theme_options['show-homepage-sidebar'] == true ){
		the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
		} else {
		the_title( sprintf( '<h2 class="entry-title-center"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
		}
		// Checks for subtitle
		$subtitle = get_post_meta ($post->ID, 'subtitle', true );
		if ( $subtitle != '' ) {
			echo '<h2 class="subtitle">' . $subtitle . '</h2>';
		}
		
		if ( 'post' === get_post_type() ) : ?>
		<div class="entry-meta">
			<?php get_template_part( 'template-parts/entry-meta'); ?>
		</div><!-- .entry-meta -->
		<?php endif; ?>
	</header><!-- .entry-header -->
	<div class="archive-thumbnail">
		<?php
		if ( has_post_thumbnail() ) { ?>
			<a href="<?php the_permalink(); ?>">
			<?php the_post_thumbnail('medium'); ?>
		</a>
	<?php } ?>
	</div>
	<div class="archive-excerpt">
		<?php
		// Check the content for the more text
		$ismore = @strpos( $post->post_content, '<!--more-->');
		// If there's a match
		if($ismore){
			the_content();
		}
		// Else no more tag exists
		else {
			the_excerpt( sprintf(
				/* translators: %s: Name of current post. */
				wp_kses( __( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'aberdeen' ), array( 'span' => array( 'class' => array() ) ) ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			) );
		}
			
			wp_link_pages( array(
				'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'aberdeen' ),
				'after'  => '</div>',
			) );
			
		// Paragraph below so that featured images don't overflow!
		?>
	<p style="clear:both;"></p>
	</div><!-- .entry-content -->
</article><!-- #post-## -->
<?php
	endwhile;
	?>
	<div class="nav-previous alignright"><?php next_posts_link( __( '<span class="nav-right">Older Posts</span><i class="fa fa-arrow-right fa-3x"></i>', 'aberdeen' ), $post_query->max_num_pages ); ?></div>
	<div class="nav-next"><?php previous_posts_link( __( '<i class="fa fa-arrow-left fa-3x"></i><span class="nav-left">Newer Posts</span>', 'aberdeen' ) ); ?></div>
	<?php
	} else {
	// no posts found
}
/* Restore original Post Data */
wp_reset_postdata();